@@ -8,9 +8,11 @@
 #
 
 import logging
+import os
 
 import yaml
 
+import climetlab
 from climetlab.core.ipython import SVG, Image
 from climetlab.core.metadata import annotation
 from climetlab.core.temporary import temp_file
@@ -22,6 +24,11 @@ from .apply import apply
 LOG = logging.getLogger(__name__)
 
 
+os.environ["MAGICS_UNITS_CONVERSIONS"] = os.path.join(
+    os.path.dirname(climetlab.__file__), "config", "units.yaml"
+)
+
+
 class Layer:
     def __init__(self, data):
         self._data = data
@@ -177,7 +184,6 @@ class Driver:
 
     def plot_xarray(self, ds, variable: str, dimensions: dict = None):
         tmp = self.temporary_file(".nc")
-        tmp = "tmp.nc"
         field = ds[variable].isel({} if dimensions is None else dimensions)
         dataset = field.to_dataset()
 
